<?php

namespace Drupal\config_layers\Entity;

use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Drupal\Core\Config\StorageInterface;

/**
 * Provides an interface for defining Configuration Layer setting entities.
 */
interface ConfigLayerInterface extends ConfigEntityInterface {

  /**
   * Layer description.
   *
   * @return string
   *   Short description.
   */
  public function getDescription();

  /**
   * Path to the file storage.
   *
   * @return string
   *   The directory path.
   */
  public function getPath();

  /**
   * Layer weight. Used to order layers during merge.
   *
   * @return int
   *   The layer weight.
   */
  public function getWeight();

  /**
   * If set, this layer will ignore merged configuration.
   *
   * @return bool
   *   Reset configuration parameter.
   */
  public function getReset();

  /**
   * The layer export mode.
   *
   * @return string
   *   Reset configuration parameter.
   */
  public function getExportMode();

  /**
   * The layer import mode.
   *
   * @return string
   *   Reset configuration parameter.
   */
  public function getImportMode();

  /**
   * Get the database storage associated with this layer.
   *
   * @return \Drupal\Core\Config\DatabaseStorage
   *   The database storage.
   */
  public function getDatabaseStorage();

  /**
   * Get the file storage associated with this layer.
   *
   * @return \Drupal\Core\Config\FileStorage
   *   The file storage.
   */
  public function getFileStorage();

  /**
   * Import the current layer.
   *
   * @param \Drupal\Core\Config\StorageInterface $source_storage
   *   The storage source storage (optional).
   * @param string $import_mode
   *   The import mode (optional).
   *
   * @return $this
   */
  public function import(StorageInterface $source_storage = NULL, $import_mode = NULL);

  /**
   * Export the current layer.
   *
   * @param \Drupal\Core\Config\StorageInterface $target_storage
   *   The target source storage (optional).
   * @param string $export_mode
   *   The export mode (optional).
   *
   * @return $this
   */
  public function export(StorageInterface $target_storage = NULL, $export_mode = NULL);

}
